from setuptools import setup

# 你的 Markdown 格式长描述（不变）
long_description = """# InterestPrint 趣味打印库
作者: 袁窦涵
邮箱: w111251@outlook.com

## 功能介绍
一款支持跨平台彩色打印、趣味喵喵环绕打印的 Python 工具库，轻量无依赖。

## 函数说明
### ColorfulPrint
带颜色的终端打印函数，支持 Windows/Linux/macOS，可选字体颜色、加粗效果。
- 参数：`*text`（打印内容）、`color`（字体颜色，默认white）、`bold`（是否加粗，默认False）、`end`（结尾字符）、`sep`（分隔符）
- 支持颜色：black/red/green/yellow/blue/purple/cyan/white

### MeowPrint
带猫咪表情环绕的趣味打印函数，可自定义前后喵数量、位置。
- 参数：`*text`（打印内容）、`meow_count`（喵表情数量，默认1）、`end`（结尾字符）、`sep`（分隔符）、`front`（是否前置喵）、`back`（是否后置喵）
"""

setup(
    name="InterestPrint",
    version="0.2.0",
    author="袁窦涵",
    author_email="w111251@outlook.com",
    description="支持各种趣味打印的 Python 工具库",
    long_description=long_description,
    long_description_content_type="text/markdown",
    py_modules=["InterestPrint"],
    install_requires=[],
    python_requires=">=3.7",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Topic :: Utilities",
    ],
    license="MIT",
)